@@ -39,13 +39,15 @@ import {
   Component, ContentChildren, QueryList, AfterViewInit
 } from '@angular/core';
 
+import { SectionBaseComponent } from './section-base.component';
+
 import { ToggleComponent } from '../variables-module/toggle.component';
 import { TickComponent } from '../variables-module/tick.component';
 import { ConditionalComponent } from '../variables-module/conditional.component';
 
 import { NumberComponent } from '../variables-module/number.component';
 import { SliderComponent } from '../variables-module/slider.component';
-import { TableComponent } from '../variables-module/table.component';
+import { VariableTableComponent } from '../variables-module/variable-table.component';
 
 import { StringComponent } from '../variables-module/string.component';
 import { DropdownComponent } from '../variables-module/dropdown.component';
@@ -56,14 +58,11 @@ import { VariableComponent } from '../types/variable-component';
 
 @Component({
   selector: 'section-live',
-  template: `<ng-content></ng-content>`
+  template: `<ng-content></ng-content><code *ngIf="code" class="language-python">{{code}}</code>`
 })
-export class LiveComponent implements AfterViewInit {
-  variableComponents: VariableComponent[] = []
-
-  liveId: number;
-  afterViewInit = false;
-  isFormReady = false;
+export class LiveComponent extends SectionBaseComponent implements AfterViewInit {
+  sectionType = 'live';
+  variableComponents: VariableComponent[] = [];
 
   @ContentChildren(ToggleComponent) toggleComponents: QueryList<ToggleComponent>;
   @ContentChildren(TickComponent) tickComponents: QueryList<TickComponent>;
@@ -71,7 +70,7 @@ export class LiveComponent implements AfterViewInit {
 
   @ContentChildren(NumberComponent) numberComponents: QueryList<NumberComponent>;
   @ContentChildren(SliderComponent) sliderComponents: QueryList<SliderComponent>;
-  @ContentChildren(TableComponent) tableComponents: QueryList<TableComponent>;
+  @ContentChildren(VariableTableComponent) variableTableComponents: QueryList<VariableTableComponent>;
 
   @ContentChildren(StringComponent) stringComponents: QueryList<StringComponent>;
   @ContentChildren(DropdownComponent) dropdownComponents: QueryList<DropdownComponent>;
@@ -79,18 +78,18 @@ export class LiveComponent implements AfterViewInit {
   @ContentChildren(CodeComponent) codeComponents: QueryList<CodeComponent>;
 
   ngAfterViewInit() {
-    this.afterViewInit = true;
+    super.ngAfterViewInit();
 
-    this.variableComponents = this.variableComponents.concat(this.toggleComponents.toArray())
-    this.variableComponents = this.variableComponents.concat(this.tickComponents.toArray())
-    this.variableComponents = this.variableComponents.concat(this.conditionalComponents.toArray())
+    this.variableComponents = this.variableComponents.concat(this.toggleComponents.toArray());
+    this.variableComponents = this.variableComponents.concat(this.tickComponents.toArray());
+    this.variableComponents = this.variableComponents.concat(this.conditionalComponents.toArray());
 
-    this.variableComponents = this.variableComponents.concat(this.numberComponents.toArray())
-    this.variableComponents = this.variableComponents.concat(this.sliderComponents.toArray())
-    this.variableComponents = this.variableComponents.concat(this.tableComponents.toArray())
+    this.variableComponents = this.variableComponents.concat(this.numberComponents.toArray());
+    this.variableComponents = this.variableComponents.concat(this.sliderComponents.toArray());
+    this.variableComponents = this.variableComponents.concat(this.variableTableComponents.toArray());
 
-    this.variableComponents = this.variableComponents.concat(this.stringComponents.toArray())
-    this.variableComponents = this.variableComponents.concat(this.dropdownComponents.toArray())
+    this.variableComponents = this.variableComponents.concat(this.stringComponents.toArray());
+    this.variableComponents = this.variableComponents.concat(this.dropdownComponents.toArray());
 
     for (const variableComponent of this.variableComponents) {
       variableComponent.variableChange.asObservable().subscribe(
@@ -98,36 +97,4 @@ export class LiveComponent implements AfterViewInit {
       );
     }
   }
-
-  set sessionId(theSessionId: string) {
-    this.initialiseCodeSessionId(theSessionId)
-  }
-
-  runCode() {
-    // This would be better done with a promise. It should always run, just
-    // delayed until read and initialised.
-    if (this.afterViewInit && this.isFormReady) {
-      this.codeComponents.toArray().forEach((codeComponent, index) => {
-        codeComponent.runCode();
-      });
-    }
-  }
-
-  formReady(isReady: boolean) {
-    this.isFormReady = isReady;
-  }
-
-  setId(id: number) {
-    this.liveId = id;
-
-    this.codeComponents.toArray().forEach((codeComponent, index) => {
-      codeComponent.name = '"live"_' + String(this.liveId) + '_' + String(index)
-    });
-  }
-
-  initialiseCodeSessionId(sessionId: string) {
-    this.codeComponents.toArray().forEach((codeComponent, index) => {
-      codeComponent.sessionId = sessionId
-    });
-  }
 }
