@@ -25,92 +25,74 @@
 // program. If not, see <http://www.apache.org/licenses/LICENSE-2.0>.
 
 
-import { Subscription } from 'rxjs';
+import { Subscription } from 'rxjs/Subscription';
 
 import {
-  Component, ContentChildren, QueryList, OnDestroy, Input, AfterViewInit,
+  Component, OnDestroy, Input, AfterViewInit,
   ViewChild
 } from '@angular/core';
 
-import { StringListParameterComponent } from "../variables-module/string-list-parameter.component";
+import { SectionBaseComponent } from './section-base.component';
+import { VariableParameterComponent } from '../variables-module/variable-parameter.component';
 
 import { WatchdogService } from '../services/watchdog.service';
 
-import { CodeComponent } from '../code-module/code.component';
-
 @Component({
   selector: 'section-filechange',
-  template: `<variable-string-list-parameter #stringListParameterComponent *ngIf="paths">
+  template: `<variable-parameter #variableParameterComponent *ngIf='paths'>
 _watchdog_path_conversion({{paths}})
-</variable-string-list-parameter><ng-content></ng-content>`
+</variable-parameter><ng-content></ng-content><code *ngIf="code" class="language-python">{{code}}</code>`
 })
-export class SectionFileChangeComponent implements OnDestroy, AfterViewInit {
-  id: number;
-  watchdogSubscription: Subscription
-  _sessionId: string
-  pathsConverted: string[]
+export class SectionFileChangeComponent extends SectionBaseComponent implements OnDestroy, AfterViewInit {
+  sectionType = 'filechange';
+  watchdogSubscription: Subscription;
+  pathsConverted: string[];
 
-  @Input() paths: string
+  @Input() paths: string;
 
-  @ContentChildren(CodeComponent) codeComponents: QueryList<CodeComponent>;
-  @ViewChild('stringListParameterComponent') stringListParameterComponent: StringListParameterComponent
+  @ViewChild('variableParameterComponent') variableParameterComponent: VariableParameterComponent;
 
   constructor(
     private myWatchdogService: WatchdogService
-  ) { }
-
-  set sessionId(theSessionId: string) {
-    this._sessionId = theSessionId
-    this.initialiseCodeSessionId(theSessionId)
-  }
+  ) { super(); }
 
   updateFilepathObserver() {
     this.pathsConverted.forEach(value => {
-      this.myWatchdogService.addFilepathObserver(value)
-    })
+      this.myWatchdogService.addFilepathObserver(value);
+    });
   }
 
   ngAfterViewInit() {
+    super.ngAfterViewInit();
     // this.updateFilepathObserver()
 
-    this.stringListParameterComponent.variableChange.asObservable().subscribe((value: string[]) => {
-      this.pathsConverted = value
-      this.updateFilepathObserver()
-    })
+    this.variableParameterComponent.variableChange.asObservable().subscribe((value: string[]) => {
+      this.pathsConverted = value;
+      this.updateFilepathObserver();
+    });
 
     this.watchdogSubscription = this.myWatchdogService.fileChanged.subscribe((value: string) => {
       if (this.pathsConverted) {
         if (
-          (this.pathsConverted.includes(value)) || 
-          (this.pathsConverted.includes(`./${value}`)) || 
+          (this.pathsConverted.includes(value)) ||
+          (this.pathsConverted.includes(`./${value}`)) ||
           (this.pathsConverted.includes(`.\\${value}`))
         ) {
-          this.runCode()
+          this.runCode();
         }
       }
-    })
-  }
-
-  runCode() {
-    this.codeComponents.toArray().forEach(codeComponent => {
-      codeComponent.runCode();
     });
   }
 
   ngOnDestroy() {
-    this.watchdogSubscription.unsubscribe()
+    this.watchdogSubscription.unsubscribe();
   }
 
-  setId(id: number) {
-    this.id = id;
-    this.codeComponents.toArray().forEach((codeComponent, index) => {
-      codeComponent.name = '"section-file"_' + String(this.id) + '_' + String(index)
-    });
-  }
-
-  initialiseCodeSessionId(sessionId: string) {
-    this.codeComponents.toArray().forEach((codeComponent, index) => {
-      codeComponent.sessionId = sessionId
+  runCode() {
+    this.viewInitPromiseDelegate.promise.then(() => {
+      this.codeComponentsArray.forEach(codeComponent => {
+        codeComponent.runCode();
+      });
     });
   }
 }
