@@ -35,17 +35,20 @@ import {
   MaterialModule
 } from '../../vendors/material.module';
 
+import { VariableBaseComponent } from './variable-base.component';
+import { NumberBaseComponent } from './number-base.component';
+
 import { ToggleComponent } from './toggle.component';
 import { TickComponent } from './tick.component';
 import { ConditionalComponent } from './conditional.component';
 
 import { NumberComponent } from './number.component';
 import { SliderComponent } from './slider.component';
-import { TableComponent } from './table.component';
+import { VariableTableComponent } from './variable-table.component';
 
 import { StringComponent } from './string.component';
 import { DropdownComponent } from './dropdown.component';
-import { StringListParameterComponent } from './string-list-parameter.component'
+import { VariableParameterComponent } from './variable-parameter.component';
 
 
 @NgModule({
@@ -55,15 +58,17 @@ import { StringListParameterComponent } from './string-list-parameter.component'
     FormsModule
   ],
   declarations: [
+    VariableBaseComponent,
+    NumberBaseComponent,
     ToggleComponent,
     TickComponent,
     ConditionalComponent,
     NumberComponent,
     SliderComponent,
-    TableComponent,
+    VariableTableComponent,
     StringComponent,
     DropdownComponent,
-    StringListParameterComponent
+    VariableParameterComponent
   ],
   exports: [
     ToggleComponent,
@@ -71,10 +76,10 @@ import { StringListParameterComponent } from './string-list-parameter.component'
     ConditionalComponent,
     NumberComponent,
     SliderComponent,
-    TableComponent,
+    VariableTableComponent,
     StringComponent,
     DropdownComponent,
-    StringListParameterComponent
+    VariableParameterComponent
   ]
 })
 export class VariablesModule { }
